<?php
namespace App\Controller\Admin;
use App\Controller\Admin\Component\ImgComponent;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\View\Helper\TimeHelper;
use Cake\Datasource\ConnectionManager;
/******************************************************************************
*File Name:	 Controller
*Creation Date: [11-02-2016]
*Modification Date: [11-02-2016]
*Author: [Raushan Suri]
*Author: [Modified By Raushan Suri]
*Description: [This controller consist of function related to Department.]
******************************************************************************/
class ExamplesController extends AppController
{

    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['showprofile']);
    }

    
    /********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function index($id=null)
    {
        $layoutTitle = 'Chat Cap :: Manage Example';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = 30;//Configure::read('App.adminPageLimit');
        
        $this->paginate = [
            'limit' => $limit,
            'order' => ['Examples.created' => 'DESC'],
			'contain'=>['Lessions'],
        ];        
        $keyword = $this->request->query('keyword');
		$condition = [];
        if($keyword != ''){
			$condition = [
				'OR' => [
					["Examples.name LIKE '%".$keyword."%'"],
					["Lessions.question LIKE '%".$keyword."%'"],
					["Lessions.Type LIKE '%".$keyword."%'"],
				]				
			];
		}        
        $query = $this->Examples->find('all')->where($condition);       
        $examples = $this->paginate($query);
        $examples = $examples->toArray();
		//pr($examples);die;
        $this->set(compact('examples', 'limit'));
    }

      
    /********************************************************************************
	Function Name: add
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to add hours.
	*********************************************************************************/
    public function add()
    {
        $layoutTitle = 'Chat Cap ::  Add New Example';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
		$this->loadModel('Lessions');
		$LessionList = $this->Lessions->find('list', ['keyField' => 'id', 'valueField' => ['question']])
						//->where(['Categories.parentId'=>'0'])
                        ->order(['Lessions.question'=>'ASC'])->toArray();
		
        $examples = $this->Examples->newEntity();        
       
        if ($this->request->is('post')) {
            
			
			$userImage = @$this->request->data['listen'];	
			unset($this->request->data['listen']);			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				//$users['profile_picture'] = $filename;
				$this->request->data['listen'] = $filename;
			}else{
				$this->request->data['listen'] = '';
			}
				
			$examples = $this->Examples->patchEntity($examples, $this->request->data, ['validate' => 'customer']);            
			$examples['created'] = date('Y-m-d H:i:s');
			//$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Examples->save($examples)) {
				if (!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/examples/';	                    
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				$this->Flash->success(__('Example added successfully.'));
				return $this->redirect(['action' => 'index']);	
			}else{
				//pr($users);die;
				$this->Flash->error(__('Unable to add new example, Please try again later.'));
			}
		}
        $this->set(compact('examples','LessionList'));
    }
    
    
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to edit hours.
	*********************************************************************************/
    public function edit($id)
    {
        $layoutTitle = 'Chat Cap :: Edit Example';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        
		$this->loadModel('Lessions');
		
						
        $examples = $this->Examples->find()->where(['Examples.id' => $id])->first();//fields name in contain[] with coma
		
		$LessionList = $this->Lessions->find('list', ['keyField' => 'id', 'valueField' => ['question']])
						->where(['Lessions.Type'=>$examples->TYPE])
                        ->order(['Lessions.question'=>'ASC'])->toArray();
						
        if ($this->request->is(['patch', 'post', 'put'])) {

			$userImage = @$this->request->data['listen'];	
			unset($this->request->data['listen']);
			$old_data = $this->Examples->get($id);            			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				$users['listen'] = $filename;
				$this->request->data['listen'] = $filename;
			}
			
			$examples = $this->Examples->patchEntity($examples, $this->request->data, ['validate' => 'customer']);
			if(!empty($filename)){				
				$oldfilename = $old_data->listen;
			}
			
			$path = WWW_ROOT . 'img/uploads/feature/examples/';
			if ($this->Examples->save($examples)) {
				if (!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/examples/';	
					@unlink(WWW_ROOT . 'img/uploads/examples/'.$oldfilename);
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				$this->Flash->success(__('The example updated successfully.'));
                return $this->redirect(['action' => 'index']);
			} else {
				
				$this->Flash->error(__('Example information could not be saved. Please try again later.'));
			}
        }
        $this->set(compact('examples','LessionList'));
    }
    
    
    /********************************************************************************
	Function Name: delete
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to delete hours permanently.
	*********************************************************************************/
    public function delete($id = null)
    {
        $users = $this->Examples->get($id);
        if ($this->Examples->delete($users)) {
            $this->Flash->success(__('Example has been deleted.'));
        } else {
            $this->Flash->error(__('Example could not be deleted. Please, try again.'));
        }
        return $this->redirect(['controller' => 'Examples', 'action' => 'index']);
    }
    
    
    /********************************************************************************
	Function Name: status
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to update hours status.
	*********************************************************************************/
    public function status($id){
		$users = $this->Examples->get($id);
		$status = '1';
		$msg = 'activated';
		if($users->status == '1'){
			$status = '0';
			$msg = 'deactivated';
		}
		
		$articles = TableRegistry::get('Examples');
		$query = $articles->query();
		$query->update()
			->set(['status' => $status])
			->where(['id' => $id])
			->execute();
		$this->Flash->success(__('Example has been '.$msg.' successfully.'));
		return $this->redirect(['controller' => 'Examples', 'action' => 'index']);
	}
    
    
    /********************************************************************************
	Function Name: details
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view hours information.
	*********************************************************************************/
    public function details($id){
        $layoutTitle = 'Chat Cap ::  Member Details';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');        
		$users = $this->Examples->find()->where(['Examples.id' => $id])->first();
        if(!empty($users)){
            $this->set(compact('users'));
        }else{
            $this->Flash->error(__('Member doesnot exist.'));
            return $this->redirect(['controller' => 'Examples', 'action' => 'index']);
        }
	}
	
	
	function getlession($id=NULL){
		$this->loadModel('Lessions');
		$LessionList = $this->Lessions->find('list', ['keyField' => 'id', 'valueField' => ['question']])
						->where(['Lessions.Type'=>$id])
                        ->order(['Lessions.question'=>'ASC'])->toArray();
		//pr($LessionList);
		$data = '<select name="lessionId" data-placeholder="Choose One" class="selectbox" style="width:100%" id="lessionid"><option value="">Select Lession</option>';
		foreach($LessionList as $key=>$Less){
			$data .='<option value="'.$key.'">'.$Less.'</option>';
		}
		$data .= '</select>';
		echo $data;
		die;
	}
	
	
}