<?php
namespace App\Controller\Admin;
use App\Controller\Admin\Component\ImgComponent;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\View\Helper\TimeHelper;
use Cake\Datasource\ConnectionManager;
/******************************************************************************
*File Name:	 Controller
*Creation Date: [11-02-2016]
*Modification Date: [11-02-2016]
*Author: [Raushan Suri]
*Author: [Modified By Raushan Suri]
*Description: [This controller consist of function related to Department.]
******************************************************************************/
class LessionsController extends AppController
{

    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['showprofile']);
    }

    
    /********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function index($id=null)
    {
        $layoutTitle = 'Chat Cap :: Manage Lession';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = 30;//Configure::read('App.adminPageLimit');
        
        $this->paginate = [
            'limit' => $limit,
            'order' => ['Lessions.created' => 'DESC'],
        ];        
        $keyword = $this->request->query('keyword');
		$condition = [];
        if($keyword != ''){
			$condition = [
				'OR' => [
					["Lessions.Type LIKE '%".$keyword."%'"],
					["Lessions.question LIKE '%".$keyword."%'"],
					["Lessions.audio LIKE '%".$keyword."%'"],
					["Lessions.screenType LIKE '%".$keyword."%'"],
					["Lessions.created LIKE '%".$keyword."%'"],
				]				
			];
		}        
        $query = $this->Lessions->find('all')->where($condition);       
        $lessions = $this->paginate($query);
        $lessions = $lessions->toArray();
		//pr($lessions);die;
        $this->set(compact('lessions', 'limit'));
    }

      
    /********************************************************************************
	Function Name: add
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to add hours.
	*********************************************************************************/
    public function add()
    {
        $layoutTitle = 'Chat Cap ::  Add New Lession';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
		
		
        $lessions = $this->Lessions->newEntity();        
       
        if ($this->request->is('post')) {
            
			
			$userImage = @$this->request->data['listen'];	
			unset($this->request->data['listen']);			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				//$users['profile_picture'] = $filename;
				$this->request->data['listen'] = $filename;
			}else{
				$this->request->data['listen'] = '';
			}
				
			$lessions = $this->Lessions->patchEntity($lessions, $this->request->data, ['validate' => 'customer']);            
			$lessions['created'] = date('Y-m-d H:i:s');
			//$path = WWW_ROOT . 'img/uploads/feature/original/';
			if ($this->Lessions->save($lessions)) {
				if (!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/lessions/';	                    
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				$this->Flash->success(__('Lession added successfully.'));
				return $this->redirect(['action' => 'index']);	
			}else{
				//pr($users);die;
				$this->Flash->error(__('Unable to add new lession, Please try again later.'));
			}
		}
        $this->set(compact('lessions','client_list'));
    }
    
    
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to edit hours.
	*********************************************************************************/
    public function edit($id)
    {
        $layoutTitle = 'Chat Cap :: Edit Lession';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        
        $lessions = $this->Lessions->find()->where(['Lessions.id' => $id])->first();//fields name in contain[] with coma
        if ($this->request->is(['patch', 'post', 'put'])) {

			@$userImage = $this->request->data['listen'];	
			unset($this->request->data['listen']);
			$old_data = $this->Lessions->get($id);            			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				$users['listen'] = $filename;
				$this->request->data['listen'] = $filename;
			}
			
			$lessions = $this->Lessions->patchEntity($lessions, $this->request->data, ['validate' => 'customer']);
			if(!empty($filename)){				
				$oldfilename = $old_data->listen;
			}
			
			$path = WWW_ROOT . 'img/uploads/feature/lessions/';
			if ($this->Lessions->save($lessions)) {
				if (!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/lessions/';	
					@unlink(WWW_ROOT . 'img/uploads/lessions/'.$oldfilename);
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
				}
				$this->Flash->success(__('The lession updated successfully.'));
                return $this->redirect(['action' => 'index']);
			} else {
				
				$this->Flash->error(__('Lession information could not be saved. Please try again later.'));
			}
        }
        $this->set(compact('lessions'));
    }
    
    
    /********************************************************************************
	Function Name: delete
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to delete hours permanently.
	*********************************************************************************/
    public function delete($id = null)
    {
        $users = $this->Lessions->get($id);
        if ($this->Lessions->delete($users)) {
            $this->Flash->success(__('Lession has been deleted.'));
        } else {
            $this->Flash->error(__('Lession could not be deleted. Please, try again.'));
        }
        return $this->redirect(['controller' => 'Lessions', 'action' => 'index']);
    }
    
    
    /********************************************************************************
	Function Name: status
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to update hours status.
	*********************************************************************************/
    public function status($id){
		$users = $this->Lessions->get($id);
		$status = '1';
		$msg = 'activated';
		if($users->status == '1'){
			$status = '0';
			$msg = 'deactivated';
		}
		
		$articles = TableRegistry::get('Lessions');
		$query = $articles->query();
		$query->update()
			->set(['status' => $status])
			->where(['id' => $id])
			->execute();
		$this->Flash->success(__('Lession has been '.$msg.' successfully.'));
		return $this->redirect(['controller' => 'Lessions', 'action' => 'index']);
	}
    
    
    /********************************************************************************
	Function Name: details
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view hours information.
	*********************************************************************************/
    public function details($id){
        $layoutTitle = 'Chat Cap ::  Member Details';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');        
		$users = $this->Lessions->find()->where(['Lessions.id' => $id])->first();
        if(!empty($users)){
            $this->set(compact('users'));
        }else{
            $this->Flash->error(__('Member doesnot exist.'));
            return $this->redirect(['controller' => 'Lessions', 'action' => 'index']);
        }
	}
	
	
}