<?php
namespace App\Controller\Admin;
use App\Controller\Admin\Component\ImgComponent;

use App\Controller\Admin\AppController;
use Cake\Event\Event;
use Cake\ORM\TableRegistry;
use Cake\Core\Configure;
use Cake\I18n\Time;
use Cake\View\Helper\TimeHelper;
/******************************************************************************
*File Name:	 DepartmentsController
*Creation Date: [11-02-2016]
*Modification Date: [11-02-2016]
*Author: [Raushan Suri]
*Author: [Modified By Raushan Suri]
*Description: [This controller consist of function related to Department.]
******************************************************************************/
class UsersController extends AppController
{

    public function beforeFilter(Event $event)
    {
        parent::beforeFilter($event);
        $this->Auth->allow(['showprofile']);
    }

    
    /********************************************************************************
	Function Name: index
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view all member list and search.
	*********************************************************************************/
    public function index()
    {
        $layoutTitle = 'Chat Cap::Manage Member';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $limit = Configure::read('App.adminPageLimit');
        
        $this->paginate = [
            'limit' => '50',//$limit,
            'order' => [
                'Users.created' => 'desc'
            ],
            //'contain' => ['ReportedProfiles']
        ];        
        $keyword = $this->request->query('keyword');
        $condition = ['Users.role !=' => 'Admin'];
        if($keyword != ''){
			$condition = [
				"Users.role != 'Admin'",
				'OR' => [
					["Users.fullName LIKE '%".$keyword."%'"],
					["Users.email LIKE '%".$keyword."%'"],
					["Users.country LIKE '%".$keyword."%'"],
					["Users.role LIKE '%".$keyword."%'"],
					["Users.contactNumber LIKE '%".$keyword."%'"]
				]				
			];
		}        
        $query = $this->Users->find('all')->where($condition);       
        $users = $this->paginate($query);
        $users = $users->toArray();
        $this->set(compact('users', 'limit'));
    }

    
   
    
    
    
    
    
    /********************************************************************************
	Function Name: add
	*Type: Public function used as action of the controller
	*Input: No input
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to add new Chat Cap member.
	*********************************************************************************/
    public function add()
    {
        $layoutTitle = 'Chat Cap::Add New Member';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        $users = $this->Users->newEntity();        
       
        if ($this->request->is('post')) {
            
            $this->request->data['username'] = $this->request->data['email']; 			
				
				  
				$userImage = $this->request->data['profile_picture'];	
				unset($this->request->data['profile_picture']);			
				if(!empty($userImage['name'])){
					$filename = time() .'_'. $userImage['name'];
					//$users['profile_picture'] = $filename;
					$this->request->data['profile_picture'] = $filename;
				}
				
				$users = $this->Users->patchEntity($users, $this->request->data, ['validate' => 'customer']);            
				$users['created'] = date('Y-m-d H:i:s'); 
				$users['role'] = 'Member'; 
				if ($this->Users->save($users)) {
					if (!empty($userImage) && $userImage['name'] != '') {
						$path = WWW_ROOT . 'img/uploads/users/original/';	                    
						move_uploaded_file($userImage['tmp_name'], $path.$filename);
						@chmod($path.$filename, 0777);
						$MyImageCom = new ImgComponent();
						$MyImageCom->prepare("img/uploads/users/original/".$filename);
						$MyImageCom->resize(150,100);
						$MyImageCom->save("img/uploads/users/thumb/".$filename);
						@chmod(WWW_ROOT."img/uploads/users/thumb/".$filename, 0777);
					}
                    $this->Flash->success(__('Member added successfully.'));
                    return $this->redirect(['action' => 'index']);	
				}else{
                    //pr($users);die;
					$this->Flash->error(__('Unable to add new member, Please try again later.'));
				}
		}
        $this->set(compact('users'));
    }
    
    
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to edit evs member.
	*********************************************************************************/
    public function edit($id)
    {
        $layoutTitle = 'Chat Cap::Edit Member';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');
        
        $users = $this->Users->find()->where(['Users.id' => $id])->first();//fields name in contain[] with coma
        if ($this->request->is(['patch', 'post', 'put'])) {
			
			if($this->request->data['password'] == '' && $this->request->data['confirm_password'] == ''){
				unset($this->request->data['password']);
				unset($this->request->data['confirm_password']);
			}			
			unset($this->request->data['email']);
			$userImage = $this->request->data['profile_picture'];	
			unset($this->request->data['profile_picture']);
			unset($users['profile_picture']);
			
			$old_data = $this->Users->get($id);            			
			if(!empty($userImage['name'])){
				$filename = time() .'_'. $userImage['name'];
				$users['profile_picture'] = $filename;
				$this->request->data['profile_picture'] = $filename;
			}	
			
			$users = $this->Users->patchEntity($users, $this->request->data, ['validate' => 'customer']);
			
			if(!empty($filename)){				
				$oldfilename = $old_data->profile_picture;
			}	
			if ($this->Users->save($users)) {								
				if (!empty($userImage) && $userImage['name'] != '') {
					$path = WWW_ROOT . 'img/uploads/users/original/';	
					@unlink(WWW_ROOT . 'img/uploads/users/original/'.$oldfilename);
					@unlink(WWW_ROOT . 'img/uploads/users/thumb/'.$oldfilename);
					move_uploaded_file($userImage['tmp_name'], $path.$filename);
					@chmod($path.$filename, 0777);
					$MyImageCom = new ImgComponent();
					$MyImageCom->prepare("img/uploads/users/original/".$filename);
					$MyImageCom->resize(150,100);
					$MyImageCom->save("img/uploads/users/thumb/".$filename);
					@chmod(WWW_ROOT."img/uploads/users/thumb/".$filename, 0777);
					
				}
				$this->Flash->success(__('The member updated successfully.'));
                return $this->redirect(['action' => 'index']);
			} else {
				$users['profile_picture'] = $old_data->profile_picture;
				$this->Flash->error(__('Member information could not be saved. Please try again later.'));
			}
        }
		$this->set(compact('countries', 'states', 'cities'));		
        $this->set(compact('users'));
    }
    
    
    /********************************************************************************
	Function Name: edit
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to delete Chat Cap member permanently.
	*********************************************************************************/
    public function delete($id = null)
    {
        $users = $this->Users->get($id);
        if ($this->Users->delete($users)) {
			@unlink(WWW_ROOT . 'img/uploads/users/original/'.$users->profilePicture);
			@unlink(WWW_ROOT . 'img/uploads/users/thumb/'.$users->profilePicture);
            $this->Flash->success(__('Member has been deleted.'));
        } else {
            $this->Flash->error(__('Member could not be deleted. Please, try again.'));
        }
        return $this->redirect(['controller' => 'Users', 'action' => 'index']);
    }
    
    
    /********************************************************************************
	Function Name: status
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to update Chat Cap member status.
	*********************************************************************************/
    public function status($id){
		$users = $this->Users->get($id);
		$query_String = $_SERVER["QUERY_STRING"];
		$status = '1';
		$msg = 'activated';
		if($users->status == '1'){
			$status = '0';
			$msg = 'deactivated';
		}
		
		$articles = TableRegistry::get('Users');
		$query = $articles->query();
		$query->update()
			->set(['status' => $status])
			->where(['id' => $id])
			->execute();
		$this->Flash->success(__('Member has been '.$msg.' successfully.'));
		
		return $this->redirect(['controller' => 'Users', 'action' => 'index/?'.$query_String]);
		
	}
    
    
	
    /********************************************************************************
	Function Name: details
	*Type: Public function used as action of the controller
	*Input: Member id
	*Author: Raushan Suri
	*Modified By: Raushan Suri
	*Output: Function to view Chat Cap member information.
	*********************************************************************************/
    public function details($id){
        $layoutTitle = 'Chat Cap::Member Details';
        $this->set(compact('layoutTitle'));
        $this->viewBuilder()->layout('Admin/admin');        
		$users = $this->Users->find()->where(['Users.id' => $id])->first();
        if(!empty($users)){
            $this->set(compact('users'));
        }else{
            $this->Flash->error(__('Member doesnot exist.'));
            return $this->redirect(['controller' => 'Users', 'action' => 'index']);
        }
	}
	
	
}